Stan Math Library: stan/math/prim/scal/prob/neg_binomial_2_rng.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

neg_binomial_2_rng.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_SCAL_PROB_NEG_BINOMIAL_2_RNG_HPP
2 #define STAN_MATH_PRIM_SCAL_PROB_NEG_BINOMIAL_2_RNG_HPP
3
4 #include <boost/math/special_functions/digamma.hpp>
5 #include <boost/random/negative_binomial_distribution.hpp>
6 #include <boost/random/variate_generator.hpp>
7 #include <stan/math/prim/scal/err/check_consistent_sizes.hpp>
8 #include <stan/math/prim/scal/err/check_positive_finite.hpp>
9 #include <stan/math/prim/scal/err/check_nonnegative.hpp>
10 #include <stan/math/prim/scal/err/check_less.hpp>
11 #include <stan/math/prim/scal/fun/constants.hpp>
12 #include <stan/math/prim/scal/fun/binomial_coefficient_log.hpp>
13 #include <stan/math/prim/scal/fun/multiply_log.hpp>
14 #include <stan/math/prim/scal/fun/digamma.hpp>
15 #include <stan/math/prim/scal/fun/lgamma.hpp>
16 #include <stan/math/prim/scal/fun/value_of.hpp>
17 #include <stan/math/prim/scal/meta/include_summand.hpp>
18 #include <stan/math/prim/scal/prob/gamma_rng.hpp>
19 #include <stan/math/prim/scal/prob/poisson_rng.hpp>
20 #include <stan/math/prim/scal/fun/grad_reg_inc_beta.hpp>
21
22 namespace stan {
23
24 namespace math {
25
26 template <class RNG>
27 inline int
28 neg_binomial_2_rng(const double mu,
29 const double phi,
30 RNG& rng) {
31 using boost::variate_generator;
32 using boost::random::negative_binomial_distribution;
33 using boost::random::poisson_distribution;
34 using boost::gamma_distribution;
35
36 static const char* function("stan::math::neg_binomial_2_rng");
37
38 check_positive_finite(function, "Location parameter", mu);
39 check_positive_finite(function, "Precision parameter", phi);
40
41 double mu_div_phi = mu/phi;
42
43 // gamma_rng params must be positive and finite
44 check_positive_finite(function,
45 "Location parameter divided by the precision parameter",
46 mu_div_phi);
47
48 double rng_from_gamma =
49 variate_generator<RNG&, gamma_distribution<> >
50 (rng, gamma_distribution<>(phi, mu_div_phi))();
51
52 // same as the constraints for poisson_rng
53 check_less(function,
54 "Random number that came from gamma distribution",
55 rng_from_gamma, POISSON_MAX_RATE);
56 check_not_nan(function,
57 "Random number that came from gamma distribution",
58 rng_from_gamma);
59 check_nonnegative(function,
60 "Random number that came from gamma distribution",
61 rng_from_gamma);
62
63 return variate_generator<RNG&, poisson_distribution<> >
64 (rng, poisson_distribution<>(rng_from_gamma))();
65 }
66 }
67 }
68 #endif
stan::math::check_less
bool check_less(const char *function, const char *name, const T_y &y, const T_high &high)
Return true if y is strictly less than high.
Definition: check_less.hpp:81
lgamma.hpp
poisson_rng.hpp
stan::math::check_not_nan
bool check_not_nan(const char *function, const char *name, const T_y &y)
Return true if y is not NaN.
Definition: check_not_nan.hpp:63
check_positive_finite.hpp
stan
Definition: log_sum_exp.hpp:8
digamma.hpp
gamma_rng.hpp
binomial_coefficient_log.hpp
include_summand.hpp
multiply_log.hpp
check_nonnegative.hpp
stan::math::neg_binomial_2_rng
int neg_binomial_2_rng(const double mu, const double phi, RNG &rng)
Definition: neg_binomial_2_rng.hpp:28
stan::math::POISSON_MAX_RATE
const double POISSON_MAX_RATE
Largest rate parameter allowed in Poisson RNG.
Definition: constants.hpp:72
grad_reg_inc_beta.hpp
constants.hpp
stan::math::check_nonnegative
bool check_nonnegative(const char *function, const char *name, const T_y &y)
Return true if y is non-negative.
Definition: check_nonnegative.hpp:66
value_of.hpp
check_less.hpp
check_consistent_sizes.hpp
stan::math::check_positive_finite
bool check_positive_finite(const char *function, const char *name, const T_y &y)
Return true if y is positive and finite.
Definition: check_positive_finite.hpp:28

[ Stan Home Page ] © 2011–2016, Stan Development Team.